[PATCH] powernow-k8: On load failure, remind the user to enable support in BIOS setup

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



 arch/x86/kernel/cpu/cpufreq/powernow-k8.c |  15 +++++++++------
 1 files changed, 9 insertions(+), 6 deletions(-)


In most cases this is simply user error or bad BIOS defaults, rather than a
firmware problem.

Signed-off-by: Marti Raudsepp <marti@xxxxxxxxx>

diff --git a/arch/x86/kernel/cpu/cpufreq/powernow-k8.c b/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
--- a/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
+++ b/arch/x86/kernel/cpu/cpufreq/powernow-k8.c
@@ -789,17 +789,20 @@
 				(struct pst_s *)(psb+1), maxvid);
 	}
 	/*
 	 * If you see this message, complain to BIOS manufacturer. If
 	 * he tells you "we do not support Linux" or some similar
 	 * nonsense, remember that Windows 2000 uses the same legacy
 	 * mechanism that the old Linux PSB driver uses. Tell them it
 	 * is broken with Windows 2000.
 	 *
 	 * The reference to the AMD documentation is chapter 9 in the
 	 * BIOS and Kernel Developer's Guide, which is available on
 	 * www.amd.com
 	 */
-	printk(KERN_ERR FW_BUG PFX "No PSB or ACPI _PSS objects\n");
+	printk(KERN_ERR PFX "No PSB or ACPI _PSS objects\n");
+	printk(KERN_ERR PFX "Make sure that Cool'N'Quiet support is "
+		"enabled in your BIOS setup\n");
 	return -ENODEV;
 }
 
@@ -789,17 +789,20 @@
 	}
 	/*
-	 * If you see this message, complain to BIOS manufacturer. If
-	 * he tells you "we do not support Linux" or some similar
-	 * nonsense, remember that Windows 2000 uses the same legacy
-	 * mechanism that the old Linux PSB driver uses. Tell them it
-	 * is broken with Windows 2000.
+	 * If you see this message, check that Cool'N'Quiet is enabled
+	 * in your BIOS setup. If that fails, complain to your BIOS
+	 * manufacturer. If he tells you "we do not support Linux" or
+	 * some similar nonsense, remember that Windows 2000 uses the
+	 * same legacy mechanism that the old Linux PSB driver uses.
+	 * Tell them it is broken with Windows 2000.
 	 *
 	 * The reference to the AMD documentation is chapter 9 in the
--
To unsubscribe from this list: send the line "unsubscribe cpufreq" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Linux Kernel Devel]     [Linux USB Devel]     [Linux Audio Users]     [Yosemite Forum]     [Linux SCSI]

  Powered by Linux